'use strict';

module.exports = function (grunt) {

  // Load grunt tasks automatically
  require('load-grunt-tasks')(grunt);

  // Time how long tasks take. Can help when optimizing build times
  require('time-grunt')(grunt);

  // Configurable paths for the application
  var appConfig = {
    app: require('./bower.json').appPath || 'app',
    dist: 'dist'
  };

  // Define the configuration for all the tasks
  grunt.initConfig({

    // Project settings modules (see build directory in root of project)
    yeoman: appConfig,

    watch: require('./build/watch'),

    connect: require('./build/connect'),

    less: require('./build/less'),

    lesslint: require('./build/lesslint'),

    jshint: require('./build/jshint'),

    clean: require('./build/clean'),

    autoprefixer: require('./build/autoprefixer'),

    wiredep: require('./build/wiredep'),

    filerev: require('./build/filerev'),

    useminPrepare: require('./build/useminprepare'),

    usemin: require('./build/usemin'),

    imagemin: require('./build/imagemin'),

    svgmin: require('./build/svgmin'),

    htmlmin: require('./build/htmlmin'),

    ngAnnotate: require('./build/ngannotate'),

    cdnify: require('./build/cdnify'),

    copy: require('./build/copy'),

    concurrent: require('./build/concurrent'),

    karma: require('./build/karma')


  });


  grunt.registerTask('serve', 'Compile then start a connect web server', function (target) {
    if (target === 'dist') {
      return grunt.task.run(['build', 'connect:dist:keepalive']);
    }

    grunt.task.run([
      'clean:server',
      'wiredep',
      'less',
      'concurrent:server',
      'autoprefixer:server',
      'connect:livereload',
      'watch'
    ]);
  });

  grunt.registerTask('server', 'DEPRECATED TASK. Use the "serve" task instead', function (target) {
    grunt.log.warn('The `server` task has been deprecated. Use `grunt serve` to start a server.');
    grunt.task.run(['serve:' + target]);
  });

  grunt.registerTask('test', [
    'clean:server',
    'wiredep',
    'concurrent:test',
    'autoprefixer',
    'connect:test',
    'karma'
  ]);

  grunt.registerTask('build', [
    'clean:dist',
    'wiredep',
    'useminPrepare',
    'concurrent:dist',
    'autoprefixer',
    'concat',
    'ngAnnotate',
    'copy:dist',
    'cdnify',
    'lesslint',
    'less',
    'cssmin',
    'uglify',
    'filerev',
    'usemin',
    'htmlmin'
  ]);

  grunt.registerTask('default', [
    'newer:jshint',
    'test',
    'build'
  ]);
};
